==> jc-1.4.0.tar.gz: jas/SourceAttr.h <==
// public class jas.SourceAttr

// class file dependencies
// @dep_class 1bd4d46265448186 jas_SourceAttr
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jas_SourceAttr_H_
#define _JC_jas_SourceAttr_H_

// Forward structure declarations
struct _jc_jas_CP$object;
struct _jc_jas_ClassEnv$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_jas_SourceAttr$sub_refs	_jc_jas_SourceAttr$sub_refs;
typedef struct _jc_jas_SourceAttr$sub_nonrefs	_jc_jas_SourceAttr$sub_nonrefs;
typedef struct _jc_jas_SourceAttr$refs	_jc_jas_SourceAttr$refs;
typedef struct _jc_jas_SourceAttr$nonrefs	_jc_jas_SourceAttr$nonrefs;
typedef struct _jc_jas_SourceAttr$object	_jc_jas_SourceAttr$object;

typedef struct _jc_jas_SourceAttr$fields_struct	_jc_jas_SourceAttr$fields_struct;
typedef const struct _jc_jas_SourceAttr$vmethods	_jc_jas_SourceAttr$vmethods;
typedef const struct _jc_jas_SourceAttr$vtable	_jc_jas_SourceAttr$vtable;
typedef const struct _jc_jas_SourceAttr$vtype	_jc_jas_SourceAttr$vtype;

// Class fields structure
struct _jc_jas_SourceAttr$fields_struct {
	struct _jc_jas_CP$object	*attr;
};
extern _jc_jas_SourceAttr$fields_struct _jc_jas_SourceAttr$class_fields;

// Constructors
extern void _jc_jas_SourceAttr$method$_init$24c6ba968508310b(_jc_env *, struct _jc_jas_SourceAttr$object *, struct _jc_jas_CP$object *);
extern void _jc_jas_SourceAttr$method$_init$c31b894660454d13(_jc_env *, struct _jc_jas_SourceAttr$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_jas_SourceAttr$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_SourceAttr$object *, struct _jc_jas_ClassEnv$object *);
extern void _jc_jas_SourceAttr$method$write$c5719140f8114b75(_jc_env *, struct _jc_jas_SourceAttr$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_jas_SourceAttr$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_SourceAttr$method_info$write$c5719140f8114b75;

// Static methods
extern void _jc_jas_SourceAttr$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_jas_SourceAttr$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_SourceAttr$object *, struct _jc_jas_ClassEnv$object *);
	void	(*write$c5719140f8114b75)(_jc_env *, struct _jc_jas_SourceAttr$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *);
};

// Vtable
struct _jc_jas_SourceAttr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_SourceAttr$vmethods	jas_SourceAttr;
};

// Vtype
struct _jc_jas_SourceAttr$vtype {
	_jc_type			type;
	_jc_jas_SourceAttr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_SourceAttr$sub_refs {
	struct _jc_jas_CP$object	*name;
};

// Reference instance fields (object)
struct _jc_jas_SourceAttr$refs {
    _jc_jas_SourceAttr$sub_refs	jas_SourceAttr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_SourceAttr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_SourceAttr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_SourceAttr$sub_nonrefs	jas_SourceAttr;
};

// Object instance structure
struct _jc_jas_SourceAttr$object {
	_jc_jas_SourceAttr$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_SourceAttr$vtype	*vtype;
	_jc_jas_SourceAttr$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_SourceAttr$vtype _jc_jas_SourceAttr$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_SourceAttr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_SourceAttr$class_object;

#endif	/* _JC_jas_SourceAttr_H_ */

==> jc-1.4.6.tar.gz: jas/SourceAttr.h <==
// public class jas.SourceAttr

// class file dependencies
// @dep_class 1bd4d46265448186 jas_SourceAttr
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jas_SourceAttr_H_
#define _JC_jas_SourceAttr_H_

// Forward structure declarations
struct _jc_jas_CP$object;
struct _jc_jas_ClassEnv$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_jas_SourceAttr$sub_refs	_jc_jas_SourceAttr$sub_refs;
typedef struct _jc_jas_SourceAttr$sub_nonrefs	_jc_jas_SourceAttr$sub_nonrefs;
typedef struct _jc_jas_SourceAttr$refs	_jc_jas_SourceAttr$refs;
typedef struct _jc_jas_SourceAttr$nonrefs	_jc_jas_SourceAttr$nonrefs;
typedef struct _jc_jas_SourceAttr$object	_jc_jas_SourceAttr$object;

typedef struct _jc_jas_SourceAttr$fields_struct	_jc_jas_SourceAttr$fields_struct;
typedef const struct _jc_jas_SourceAttr$vmethods	_jc_jas_SourceAttr$vmethods;
typedef const struct _jc_jas_SourceAttr$vtable	_jc_jas_SourceAttr$vtable;
typedef const struct _jc_jas_SourceAttr$vtype	_jc_jas_SourceAttr$vtype;

// Class fields structure
struct _jc_jas_SourceAttr$fields_struct {
	struct _jc_jas_CP$object	*attr;
};
extern _jc_jas_SourceAttr$fields_struct _jc_jas_SourceAttr$class_fields;

// Constructors
extern void _jc_jas_SourceAttr$method$_init$24c6ba968508310b(_jc_env *, struct _jc_jas_SourceAttr$object *, struct _jc_jas_CP$object *) _JC_JCNI_ATTR;
extern void _jc_jas_SourceAttr$method$_init$c31b894660454d13(_jc_env *, struct _jc_jas_SourceAttr$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_jas_SourceAttr$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_SourceAttr$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
extern void _jc_jas_SourceAttr$method$write$c5719140f8114b75(_jc_env *, struct _jc_jas_SourceAttr$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_jas_SourceAttr$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_SourceAttr$method_info$write$c5719140f8114b75;

// Static methods
extern void _jc_jas_SourceAttr$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_jas_SourceAttr$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_SourceAttr$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
	void	(*write$c5719140f8114b75)(_jc_env *, struct _jc_jas_SourceAttr$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_jas_SourceAttr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_SourceAttr$vmethods	jas_SourceAttr;
};

// Vtype
struct _jc_jas_SourceAttr$vtype {
	_jc_type			type;
	_jc_jas_SourceAttr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_SourceAttr$sub_refs {
	struct _jc_jas_CP$object	*name;
};

// Reference instance fields (object)
struct _jc_jas_SourceAttr$refs {
    _jc_jas_SourceAttr$sub_refs	jas_SourceAttr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_SourceAttr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_SourceAttr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_SourceAttr$sub_nonrefs	jas_SourceAttr;
};

// Object instance structure
struct _jc_jas_SourceAttr$object {
	_jc_jas_SourceAttr$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_SourceAttr$vtype	*vtype;
	_jc_jas_SourceAttr$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_SourceAttr$vtype _jc_jas_SourceAttr$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_SourceAttr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_SourceAttr$class_object;

#endif	/* _JC_jas_SourceAttr_H_ */
